# Perrot

The *perrot* library is an extension of the original [*pero*](https://github.com/xxao/pero/) drawing library
to make simple plots and charts. Please see the [examples](https://github.com/xxao/perrot/tree/master/examples) folder
or in-code documentation of classes and functions to learn more about the *perrot* library capabilities.
I also strongly recommend to check details of the [*pero*](https://github.com/xxao/pero/) itself.

*Please note that the library is currently under heavy development and significant changes are made regularly. Feel free
to try the library but please do not expect it to be stable.*

## Requirements

- [Python 3.6+](https://www.python.org)
- [Numpy](https://pypi.org/project/numpy/)
- [Pero](https://github.com/xxao/pero/)


## Installation

The *perrot* library is fully implemented in Python. No additional compiler is necessary. After downloading the source
code just run the following command from the *perrot* folder:

```$ python setup.py install```

or simply use pip

```$ pip install perrot```


## Examples

In the [examples](https://github.com/xxao/perrot/tree/master/examples) folder you will find sample codes to generate and
understand all the following images. Check the image name and find corresponding python draw file.

<p>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/annotations.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/arrows.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/assembly.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/axes.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/band.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/bars.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/histogram.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/multiplot.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/profile.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/scatter.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/stacks.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/heatmap.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/venn.png" height="150"/>
    <img src="https://raw.githubusercontent.com/xxao/perrot/master/examples/images/piechart.png" height="150"/>
</p>


## Disclaimer

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

Please note that the *pero* library is still in an alpha state. Any changes in its API may occur.